## vegafusion-runtime
This crate contains the logic for evaluating the task graphs that are generated by `vegafusion-core`. Task graph evaluation involes:
 - Compiling Vega expression ASTs to DataFusion expressions.
 - Evaluating signal expression tasks
 - Evaluating Data tasks, including transform pipelines. Transforms are implemented against the DataFrame trait provided by `vegafusion-dataframe`.
 - Pre-transforming Vega specifications by pre-evaluating their transforms and inlining the resulting transformed data.
